# prt_phasecurve

Bulding phasecurves of exoplanetary atmospheres using petitradtrans

## Install:

```
pip install prt_phasecurve
```

## Currently usable functions:

Integrate the global spectra to calculate the phase curve:
```
phase_curve()
```

Calculate the spectra of the (lowres) GCM output:
```
calc_spectra()
```

TODO: Add more information here
